==> haskell-quickcheck-classes-0.6.5.0-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quickcheck-classes
version:              0.6.5.0
visibility:           public
id:                   quickcheck-classes-0.6.5.0-1J41NGXUrJYLRTcEK3tEnh
key:                  quickcheck-classes-0.6.5.0-1J41NGXUrJYLRTcEK3tEnh
license:              BSD-3-Clause
copyright:            2018 Andrew Martin
maintainer:           andrew.thaddeus@gmail.com
author:               Andrew Martin, chessai
homepage:             https://github.com/andrewthad/quickcheck-classes#readme
synopsis:             QuickCheck common typeclasses
description:
    This library provides QuickCheck properties to ensure
    that typeclass instances adhere to the set of laws that
    they are supposed to. There are other libraries that do
    similar things, such as `genvalidity-hspec` and `checkers`.
    This library differs from other solutions by not introducing
    any new typeclasses that the user needs to learn.

    /Note:/ on GHC < 8.5, this library uses the higher-kinded typeclasses
    ('\''Data.Functor.Classes.Show1'\'', '\''Data.Functor.Classes.Eq1'\'', '\''Data.Functor.Classes.Ord1'\'', etc.),
    but on GHC >= 8.5, it uses `-XQuantifiedConstraints` to express these
    constraints more cleanly.

category:             Testing
abi:                  a1fcff15e336d3836e3f89dd4d9b409d
exposed:              True
exposed-modules:
    Test.QuickCheck.Classes Test.QuickCheck.Classes.IsList

hidden-modules:
    Test.QuickCheck.Classes.Alt Test.QuickCheck.Classes.Apply
    Test.QuickCheck.Classes.Euclidean Test.QuickCheck.Classes.Json
    Test.QuickCheck.Classes.MVector Test.QuickCheck.Classes.Plus
    Test.QuickCheck.Classes.Prim Test.QuickCheck.Classes.Semigroupoid
    Test.QuickCheck.Classes.Semiring Test.QuickCheck.Classes.Ring

import-dirs:          /usr/lib/ghc-9.0.2/site-local/quickcheck-classes-0.6.5.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/quickcheck-classes-0.6.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-classes
hs-libraries:         HSquickcheck-classes-0.6.5.0-1J41NGXUrJYLRTcEK3tEnh
depends:
    QuickCheck-2.14.2-CKku5U4XaTZ1OrrQj3RQZM
    aeson-1.5.6.0-GZUW0RX6wR0GNyId2zbUZx base-4.15.1.0
    containers-0.6.4.1 primitive-0.7.3.0-4YY3VSdWTqoii1vz058dN
    primitive-addr-0.1.0.2-J2JiXFimckNAOegvH1HXSK
    quickcheck-classes-base-0.6.2.0-9vrWMeqv2fVS0YSglXJj7
    semigroupoids-5.3.7-5Xe3mmrUnJFL7evkYKNqog
    semirings-0.6-7TqHW3wHxvBFtTF2d34q1P transformers-0.5.6.2
    vector-0.12.3.1-35O4ef8MZDE9Y9qFX9F3Ug

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-classes/html/quickcheck-classes.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-classes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-classes-0.6.5.0-81-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quickcheck-classes
version:              0.6.5.0
visibility:           public
id:                   quickcheck-classes-0.6.5.0-2ioa0X4wAICKlVAJoXspxQ
key:                  quickcheck-classes-0.6.5.0-2ioa0X4wAICKlVAJoXspxQ
license:              BSD-3-Clause
copyright:            2018 Andrew Martin
maintainer:           andrew.thaddeus@gmail.com
author:               Andrew Martin, chessai
homepage:             https://github.com/andrewthad/quickcheck-classes#readme
synopsis:             QuickCheck common typeclasses
description:
    This library provides QuickCheck properties to ensure
    that typeclass instances adhere to the set of laws that
    they are supposed to. There are other libraries that do
    similar things, such as `genvalidity-hspec` and `checkers`.
    This library differs from other solutions by not introducing
    any new typeclasses that the user needs to learn.

    /Note:/ on GHC < 8.5, this library uses the higher-kinded typeclasses
    ('\''Data.Functor.Classes.Show1'\'', '\''Data.Functor.Classes.Eq1'\'', '\''Data.Functor.Classes.Ord1'\'', etc.),
    but on GHC >= 8.5, it uses `-XQuantifiedConstraints` to express these
    constraints more cleanly.

category:             Testing
abi:                  97cbbb2a6ddb05511d78d922cb7b1f8b
exposed:              True
exposed-modules:
    Test.QuickCheck.Classes Test.QuickCheck.Classes.IsList

hidden-modules:
    Test.QuickCheck.Classes.Alt Test.QuickCheck.Classes.Apply
    Test.QuickCheck.Classes.Euclidean Test.QuickCheck.Classes.Json
    Test.QuickCheck.Classes.MVector Test.QuickCheck.Classes.Plus
    Test.QuickCheck.Classes.Prim Test.QuickCheck.Classes.Semigroupoid
    Test.QuickCheck.Classes.Semiring Test.QuickCheck.Classes.Ring

import-dirs:          /usr/lib/ghc-9.0.2/site-local/quickcheck-classes-0.6.5.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/quickcheck-classes-0.6.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-classes
hs-libraries:         HSquickcheck-classes-0.6.5.0-2ioa0X4wAICKlVAJoXspxQ
depends:
    QuickCheck-2.14.2-7iK1DMIteZqGNM8TzExDZa
    aeson-1.5.6.0-9Pr07X4KYAQGYkzJzuJMP6 base-4.15.1.0
    containers-0.6.4.1 primitive-0.7.4.0-1OkI0w4vVkZAnKazzRI3t
    primitive-addr-0.1.0.2-FNzVZSE7lq52d49WLpZDZY
    quickcheck-classes-base-0.6.2.0-K91Po2NRJvWJK54nu3dM9m
    semigroupoids-5.3.7-5B78CVm23hgLq9eADr8PDI
    semirings-0.6-2l0UEnaizDK72SY8U0g0rM transformers-0.5.6.2
    vector-0.12.3.1-J4wWiZyTUBGFVf3h0yMQvX

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-classes/html/quickcheck-classes.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-classes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
